summaryrefslogtreecommitdiff
path: root/source3/lib
diff options
context:
space:
mode:
authorGünther Deschner <gd@samba.org>2010-05-18 03:25:38 +0200
committerGünther Deschner <gd@samba.org>2010-05-18 12:30:11 +0200
commita8b01d1f3b4025af7e7a9d8b61deec6156737322 (patch)
tree46f560cfd41acc773857a0cd890fa09e9862a2ef /source3/lib
parent8bc9c343c4fe4e6f6c0283fd15e86caf6b8c1085 (diff)
downloadsamba-a8b01d1f3b4025af7e7a9d8b61deec6156737322.tar.gz
samba-a8b01d1f3b4025af7e7a9d8b61deec6156737322.tar.bz2
samba-a8b01d1f3b4025af7e7a9d8b61deec6156737322.zip
s3-secdesc: remove "typedef struct security_ace SEC_ACE".
Guenther
Diffstat (limited to 'source3/lib')
-rw-r--r--source3/lib/secdesc.c18
-rw-r--r--source3/lib/sharesec.c6
-rw-r--r--source3/lib/util_nttoken.c2
3 files changed, 13 insertions, 13 deletions
diff --git a/source3/lib/sharesec.c b/source3/lib/sharesec.c
index a1a543e6a1..5aaadece3f 100644
--- a/source3/lib/sharesec.c
+++ b/source3/lib/sharesec.c
@@ -228,7 +228,7 @@ bool share_info_db_init(void)
SEC_DESC *get_share_security_default( TALLOC_CTX *ctx, size_t *psize, uint32 def_access)
{
uint32_t sa;
- SEC_ACE ace;
+ struct security_ace ace;
SEC_ACL *psa = NULL;
SEC_DESC *psd = NULL;
uint32 spec_access = def_access;
@@ -435,7 +435,7 @@ bool parse_usershare_acl(TALLOC_CTX *ctx, const char *acl_str, SEC_DESC **ppsd)
size_t s_size = 0;
const char *pacl = acl_str;
int num_aces = 0;
- SEC_ACE *ace_list = NULL;
+ struct security_ace *ace_list = NULL;
SEC_ACL *psa = NULL;
SEC_DESC *psd = NULL;
size_t sd_size = 0;
@@ -458,7 +458,7 @@ bool parse_usershare_acl(TALLOC_CTX *ctx, const char *acl_str, SEC_DESC **ppsd)
/* Add the number of ',' characters to get the number of aces. */
num_aces += count_chars(pacl,',');
- ace_list = TALLOC_ARRAY(ctx, SEC_ACE, num_aces);
+ ace_list = TALLOC_ARRAY(ctx, struct security_ace, num_aces);
if (!ace_list) {
return False;
}
diff --git a/source3/lib/util_nttoken.c b/source3/lib/util_nttoken.c
index 76e7402422..edacafd91b 100644
--- a/source3/lib/util_nttoken.c
+++ b/source3/lib/util_nttoken.c
@@ -117,7 +117,7 @@ NTSTATUS merge_nt_token(TALLOC_CTX *mem_ctx,
}
/*******************************************************************
- Check if this ACE has a SID in common with the token.
+ Check if this struct security_ace has a SID in common with the token.
********************************************************************/
bool token_sid_in_ace(const NT_USER_TOKEN *token, const struct security_ace *ace)
diff --git a/source3/lib/secdesc.c b/source3/lib/secdesc.c
index b3505e7e1b..a540aa684c 100644
--- a/source3/lib/secdesc.c
+++ b/source3/lib/secdesc.c
@@ -413,7 +413,7 @@ NTSTATUS sec_desc_add_sid(TALLOC_CTX *ctx, SEC_DESC **psd, DOM_SID *sid, uint32
{
SEC_DESC *sd = 0;
SEC_ACL *dacl = 0;
- SEC_ACE *ace = 0;
+ struct security_ace *ace = 0;
NTSTATUS status;
if (!ctx || !psd || !sid || !sd_size)
@@ -465,7 +465,7 @@ NTSTATUS sec_desc_del_sid(TALLOC_CTX *ctx, SEC_DESC **psd, DOM_SID *sid, size_t
{
SEC_DESC *sd = 0;
SEC_ACL *dacl = 0;
- SEC_ACE *ace = 0;
+ struct security_ace *ace = 0;
NTSTATUS status;
if (!ctx || !psd[0] || !sid || !sd_size)
@@ -491,10 +491,10 @@ NTSTATUS sec_desc_del_sid(TALLOC_CTX *ctx, SEC_DESC **psd, DOM_SID *sid, size_t
}
/*
* Determine if an ACE is inheritable
*/
-static bool is_inheritable_ace(const SEC_ACE *ace,
+static bool is_inheritable_ace(const struct security_ace *ace,
bool container)
{
if (!container) {
@@ -524,7 +524,7 @@ bool sd_has_inheritable_components(const SEC_DESC *parent_ctr, bool container)
const SEC_ACL *the_acl = parent_ctr->dacl;
for (i = 0; i < the_acl->num_aces; i++) {
- const SEC_ACE *ace = &the_acl->aces[i];
+ const struct security_ace *ace = &the_acl->aces[i];
if (is_inheritable_ace(ace, container)) {
return true;
@@ -546,7 +546,7 @@ NTSTATUS se_create_child_secdesc(TALLOC_CTX *ctx,
bool container)
{
SEC_ACL *new_dacl = NULL, *the_acl = NULL;
- SEC_ACE *new_ace_list = NULL;
+ struct security_ace *new_ace_list = NULL;
unsigned int new_ace_list_ndx = 0, i;
*ppsd = NULL;
@@ -563,7 +563,7 @@ NTSTATUS se_create_child_secdesc(TALLOC_CTX *ctx,
return NT_STATUS_NO_MEMORY;
}
- if (!(new_ace_list = TALLOC_ARRAY(ctx, SEC_ACE,
+ if (!(new_ace_list = TALLOC_ARRAY(ctx, struct security_ace,
2*the_acl->num_aces))) {
return NT_STATUS_NO_MEMORY;
}
@@ -572,8 +572,8 @@ NTSTATUS se_create_child_secdesc(TALLOC_CTX *ctx,
}
for (i = 0; i < the_acl->num_aces; i++) {
- const SEC_ACE *ace = &the_acl->aces[i];
- SEC_ACE *new_ace = &new_ace_list[new_ace_list_ndx];
+ const struct security_ace *ace = &the_acl->aces[i];
+ struct security_ace *new_ace = &new_ace_list[new_ace_list_ndx];
const DOM_SID *ptrustee = &ace->trustee;
const DOM_SID *creator = NULL;
uint8 new_flags = ace->flags;
@@ -491,10 +491,10 @@ NTSTATUS sec_desc_del_sid(TALLOC_CTX *ctx, SEC_DESC **psd, DOM_SID *sid, size_t
}
/*
- * Determine if an ACE is inheritable
+ * Determine if an struct security_ace is inheritable
*/